gevent is technically a member project of the Software Freedom
Conservancy, and used to accept donations to them. However, while all
of the donations have been much appreciated, none of the gevent
developers have ever been able to access these donations. For that
reason, gevent is no longer accepting donations.

..
 <div class="section" id="donate">
 <h1>Donate<a class="headerlink" href="#donate" title="Permalink to this headline">¶</a></h1>
 <p></p><p>Gevent is a member project of the <a href="http://sfconservancy.org">Software Freedom Conservancy</a>. The SFC is a not-for-profit organization that provides financial and administrative assistance to open source projects.</p>
 <table>
 <tbody><tr>
 <td><b>Donate with PayPal</b></td>
 </tr>
 <tr>
 <td>

 <form action="https://www.paypal.com/cgi-bin/webscr" method="post">
 <input type="hidden" name="cmd" value="_s-xclick">
 <input type="hidden" name="hosted_button_id" value="WWTKXX5YS5GSU">

 <input type="image" src="https://www.paypal.com/en_US/i/btn/btn_donateCC_LG.gif" border="0" name="submit" alt="PayPal - The safer, easier way to pay online!">
 <img alt="" border="0" src="https://www.paypal.com/en_US/i/scr/pixel.gif" width="0" height="0" style="display: none !important; visibility: hidden !important; opacity: 0 !important; background-position: 1px 1px;">
 </form>

 </td>
 </tr>

 </tbody></table>

 <b>Donations by check</b>
 <p>
 We can also accept donations drawn in USD from banks in the USA (donations from banks outside of the US or not in USD should be handled by wire).

 Make checks payable to "Software Freedom Conservancy, Inc." and place "Directed donation: Gevent" in the memo field. Checks should be mailed to:
 </p>

 <pre style="background: white; border: 0px;">Software Freedom Conservancy, Inc.
 137 Montague ST  STE 380
 BROOKLYN, NY 11201
 USA
 </pre>
 <p>
 The SFC can accept wire donations, but the instructions vary depending on the country of origin. Please contact accounting@sfconservancy.org for instructions.</p>
 <p></p>
 </div>
 </div>
 </div>
 </div>
 </div>
 </div>
